
.. currentmodule:: tibs

.. figure:: ./tibs.png

   A sleek Python library for binary data



**tibs** is a simple but powerful Python library for creating, interpreting and manipulating binary data.
It is 100% written in Rust, and from the same author as the `bitstring <https://github.com/scott-griffiths/bitstring>`_ library.

.. note::

    The project is currently in alpha. This documentation is incomplete.

----

.. toctree::
    :maxdepth: 1

    intro
    examples
    api



